@@ -503,9 +503,10 @@
         // The spec is ambiguous here, see
         // https://github.com/WebAssembly/spec/issues/1138. The WPT tests
         // expect the raw value of the Content-Type attribute lowercased.
+        const contentType = res.headers.get("Content-Type");
         if (
-          StringPrototypeToLowerCase(res.headers.get("Content-Type")) !==
-            "application/wasm"
+          typeof contentType !== "string" ||
+          StringPrototypeToLowerCase(contentType) !== "application/wasm"
         ) {
           throw new TypeError("Invalid WebAssembly content type.");
         }
@@ -523,15 +524,15 @@
           while (true) {
             const { value: chunk, done } = await reader.read();
             if (done) break;
-            Deno.core.wasmStreamingFeed(rid, "bytes", chunk);
+            core.wasmStreamingFeed(rid, "bytes", chunk);
           }
         }
 
         // 2.7.
-        Deno.core.wasmStreamingFeed(rid, "finish");
+        core.wasmStreamingFeed(rid, "finish");
       } catch (err) {
         // 2.8 and 3
-        Deno.core.wasmStreamingFeed(rid, "abort", err);
+        core.wasmStreamingFeed(rid, "abort", err);
       }
     })();
   }
