@@ -1,7 +1,6 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 
 use data_url::DataUrl;
-use deno_core::error::bad_resource_id;
 use deno_core::error::null_opbuf;
 use deno_core::error::type_error;
 use deno_core::error::AnyError;
@@ -53,7 +52,9 @@ use tokio::sync::mpsc;
 use tokio_stream::wrappers::ReceiverStream;
 use tokio_util::io::StreamReader;
 
-pub use reqwest; // Re-export reqwest
+// Re-export reqwest and data_url
+pub use data_url;
+pub use reqwest;
 
 pub fn init<P: FetchPermissions + 'static>(
   user_agent: String,
@@ -64,7 +65,7 @@ pub fn init<P: FetchPermissions + 'static>(
 ) -> Extension {
   Extension::builder()
     .js(include_js_files!(
-      prefix "deno:extensions/fetch",
+      prefix "deno:ext/fetch",
       "01_fetch_util.js",
       "20_headers.js",
       "21_formdata.js",
@@ -163,10 +164,7 @@ where
   FP: FetchPermissions + 'static,
 {
   let client = if let Some(rid) = args.client_rid {
-    let r = state
-      .resource_table
-      .get::<HttpClientResource>(rid)
-      .ok_or_else(bad_resource_id)?;
+    let r = state.resource_table.get::<HttpClientResource>(rid)?;
     r.client.clone()
   } else {
     let client = state.borrow::<reqwest::Client>();
@@ -345,8 +343,7 @@ pub async fn op_fetch_send(
   let request = state
     .borrow_mut()
     .resource_table
-    .take::<FetchRequestResource>(rid)
-    .ok_or_else(bad_resource_id)?;
+    .take::<FetchRequestResource>(rid)?;
 
   let request = Rc::try_unwrap(request)
     .ok()
@@ -402,8 +399,7 @@ pub async fn op_fetch_request_write(
   let resource = state
     .borrow()
     .resource_table
-    .get::<FetchRequestBodyResource>(rid)
-    .ok_or_else(bad_resource_id)?;
+    .get::<FetchRequestBodyResource>(rid)?;
   let body = RcRef::map(&resource, |r| &r.body).borrow_mut().await;
   let cancel = RcRef::map(resource, |r| &r.cancel);
   body.send(Ok(buf)).or_cancel(cancel).await?.map_err(|_| {
@@ -423,8 +419,7 @@ pub async fn op_fetch_response_read(
   let resource = state
     .borrow()
     .resource_table
-    .get::<FetchResponseBodyResource>(rid)
-    .ok_or_else(bad_resource_id)?;
+    .get::<FetchResponseBodyResource>(rid)?;
   let mut reader = RcRef::map(&resource, |r| &r.reader).borrow_mut().await;
   let cancel = RcRef::map(resource, |r| &r.cancel);
   let mut buf = data.clone();
